'use strict'

const Transform = require('stream').Transform

/**
 * Create a Transform stream which will maintain a buffer with data received from a Readable
 * stream and push data to a Writable stream when the buffer can be matched againts the regex.
 * Will push the whole match object (or objects when the g flag is used) returned by
 * /regex/.exec(buffer).
 * @param {RegExp} regex Regular expression to execute
 * @return {Transform} A transform stream.
 */
function createRegexTransformStream(regex) {
    let buffer = ''

    const ts = new Transform({ objectMode: true })

    ts._transform = (chunk, _, next) => {
        let lastMatch
        let match
        buffer += chunk.toString()

        // thx stream-snitch
        // https://github.com/dmotz/stream-snitch/blob/master/index.js#L52
        // eslint-disable-next-line no-cond-assign
        while (match = regex.exec(buffer)) {
            ts.push(match)
            lastMatch = match
            if (!regex.global) break
        }
        if (lastMatch) {
            buffer = buffer.slice(lastMatch.index + lastMatch[0].length)
        }
        next()
    }

    return ts
}

module.exports = createRegexTransformStream
